@@ -1,17 +1,17 @@
 ;(function(){
   var map = {
-  "commitId": "f9fbb1a1210e9704c0a40d64dfa655179c506ad6",
-  "branchName": "release-client-5.x",
-  "buildTime": "2023-06-17 12:13:53 GMT",
-  "buildVersion": "5.1.452",
+  "commitId": "0731d0b3d739c2846a441a55147cf53cd5301cf7",
+  "branchName": "release-client-5.15.1",
+  "buildTime": "2023-07-06 07:18:20 GMT",
+  "buildVersion": "5.1.473",
   "css": [
-    "@zoom/client-calendar/static/css/default~app.2c022cc9.css",
+    "@zoom/client-calendar/static/css/default~app.7424f5e7.css",
     "@zoom/client-calendar/static/css/vendors~app.dc891ce4.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/default~app.d2af72c2.js",
-    "@zoom/client-calendar/static/js/vendors~app.f5b33390.js",
-    "@zoom/client-calendar/static/js/app.01d92ee2.js"
+    "@zoom/client-calendar/static/js/default~app.6af0a321.js",
+    "@zoom/client-calendar/static/js/vendors~app.b1310e99.js",
+    "@zoom/client-calendar/static/js/app.9f5f79d9.js"
   ],
   "key": "@zoom/client-calendar"
 };
